Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp

Issue 1421113006: Detach the globals of all frames, not just the main frame (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: git cl try Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp
diff --git a/third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp b/third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp
index 5cef9ae17ea0f16e8d04ce08bb6d7a5e040d93e9..624d25b0130fa3fb55fcfdc8a830b9bdd0624595 100644
--- a/third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp
+++ b/third_party/WebKit/Source/bindings/core/v8/WindowProxy.cpp
@@ -91,7 +91,7 @@ WindowProxy::WindowProxy(Frame* frame, PassRefPtr<DOMWrapperWorld> world, v8::Is
WindowProxy::~WindowProxy()
{
// clearForClose() or clearForNavigation() must be invoked before destruction starts.
ASSERT(!isContextInitialized());
}
@@ -127,15 +127,7 @@ void WindowProxy::disposeContext(GlobalDetachmentBehavior behavior)
V8GCForContextDispose::instance().notifyContextDisposed(m_frame->isMainFrame());
}
-void WindowProxy::clearForClose()
-{
- if (!isContextInitialized())
- return;
-
- disposeContext(DoNotDetachGlobal);
-}
-
-void WindowProxy::clearForNavigation()
+void WindowProxy::clearWindowProxy()
{
if (!isContextInitialized())
return;
@@ -149,7 +141,7 @@ v8::Local<v8::Object> WindowProxy::releaseGlobal()
{
ASSERT(!isContextInitialized());
// If a ScriptState was created, the context was initialized at some point.
// Make sure the global object was detached from the proxy by calling clearForNavigation().
if (m_scriptState)
ASSERT(m_scriptState->isGlobalObjectDetached());
v8::Local<v8::Object> global = m_global.newLocal(m_isolate);
@@ -91,7 +91,7 @@ WindowProxy::WindowProxy(Frame* frame, PassRefPtr<DOMWrapperWorld> world, v8::Is
WindowProxy::~WindowProxy()
{
- // clearForClose() or clearForNavigation() must be invoked before destruction starts.
+ // clearWindowProxy() must be invoked before destruction starts.
ASSERT(!isContextInitialized());
}
@@ -149,7 +141,7 @@ v8::Local<v8::Object> WindowProxy::releaseGlobal()
ASSERT(!isContextInitialized());
// If a ScriptState was created, the context was initialized at some point.
- // Make sure the global object was detached from the proxy by calling clearForNavigation().
+ // Make sure the global object was detached from the proxy by calling clearWindowProxy().
if (m_scriptState)
ASSERT(m_scriptState->isGlobalObjectDetached());

Powered by Google App Engine
This is Rietveld 408576698